{% extends "dcf/_base.html" %}

{% block title %}{{ object }}{% endblock %}

{% block body %}
    <div class="row">
        <div class="col-lg-12">
            <h1>
              <a href="{{ object.get_absolute_url }}" title="{{ object.title }}">
                {{ object.title }}
                </a>
            </h1>
        </div>
    </div>

    <div class="row">
        <div class="col-lg-12">
            {% include "dcf/item_list.inc.html" %}
        </div>
    </div>

    <div class="row">
        <div class="col-lg-12">
            {% include "dcf/list_pagination.inc.html" %}
        </div>
    </div>
{% endblock body %}